COMPMID-414 - Port CLConvolutionLayer to support 8 bit fixed point - CLWeightsReshapeKernel

Change-Id: Ie32e6bdd557a8243eb9988aa7eab4e4ca2291e79
Reviewed-on: http://mpd-gerrit.cambridge.arm.com/78701
Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com>
Reviewed-by: Moritz Pflanzer <moritz.pflanzer@arm.com>
diff --git a/arm_compute/runtime/CL/functions/CLLocallyConnectedLayer.h b/arm_compute/runtime/CL/functions/CLLocallyConnectedLayer.h
index b4e4691..5f4f1ba 100644
--- a/arm_compute/runtime/CL/functions/CLLocallyConnectedLayer.h
+++ b/arm_compute/runtime/CL/functions/CLLocallyConnectedLayer.h
@@ -39,7 +39,7 @@
 
 /** Basic function to compute the locally connected layer. This function calls the following OpenCL kernels:
  *
  * -# @ref CLLocallyConnectedLayerWeightsReshapeKernel (executed only once for each configuration)
  * -# @ref CLIm2ColKernel
  * -# @ref CLLocallyConnectedMatrixMultiplyKernel
  * -# @ref CLCol2ImKernel
@@ -66,14 +66,14 @@
     void run() override;
 
 private:
-    CLIm2ColKernel                              _input_im2col_kernel;
-    CLLocallyConnectedLayerWeightsReshapeKernel _weights_reshape_kernel;
-    CLLocallyConnectedMatrixMultiplyKernel      _mm_kernel;
-    CLCol2ImKernel                              _output_col2im_kernel;
-    CLTensor                                    _input_im2col_reshaped;
-    CLTensor                                    _weights_reshaped;
-    CLTensor                                    _gemm_output;
-    bool                                        _is_first_run;
+    CLIm2ColKernel                         _input_im2col_kernel;
+    CLWeightsReshapeKernel                 _weights_reshape_kernel;
+    CLLocallyConnectedMatrixMultiplyKernel _mm_kernel;
+    CLCol2ImKernel                         _output_col2im_kernel;
+    CLTensor                               _input_im2col_reshaped;
+    CLTensor                               _weights_reshaped;
+    CLTensor                               _gemm_output;
+    bool                                   _is_first_run;
 };
 }
 #endif /* __ARM_COMPUTE_CLLOCALLYCONNECTEDLAYER_H__ */
@@ -39,7 +39,7 @@
 /** Basic function to compute the locally connected layer. This function calls the following OpenCL kernels:
  *
- * -# @ref CLLocallyConnectedLayerWeightsReshapeKernel (executed only once for each configuration)
+ * -# @ref CLWeightsReshapeKernel (executed only once for each configuration)
  * -# @ref CLIm2ColKernel
  * -# @ref CLLocallyConnectedMatrixMultiplyKernel